@@ -48,7 +48,7 @@ PYDIST_RE = re.compile(r"""
     (?P<dependency>(?:[a-z][^;]*)?)              # Debian dependency
     (?:  # optional upstream version -> Debian version translator
         ;\s*
-        (?P<standard>PEP386)?                    # PEP-386 mode
+        (?P<standard>PEP386|PEP440)?             # PEP-386 / PEP-440 mode
         \s*
         (?P<rules>(?:s|tr|y).*)?                 # translator rules
     )?
@@ -355,22 +355,23 @@ def check_environment_marker_restrictions(req, marker_str, impl):
 
     elif marker in ('python_version', 'python_full_version',
                         'implementation_version'):
+        # TODO: Replace with full PEP-440 parser
         env_ver = value
-        int_ver = value.split('.')
+        split_ver = value.split('.')
         if marker == 'python_version':
             version_parts = 2
         elif marker == 'python_full_version':
             version_parts = 3
         else:
-            version_parts = len(int_ver)
+            version_parts = len(split_ver)
 
         if '*' in env_ver:
-            if int_ver.index('*') != len(int_ver) -1:
+            if split_ver.index('*') != len(split_ver) -1:
                 log.info('Skipping requirement with intermediate wildcard: %s',
                          req)
                 return False
-            int_ver.pop()
-            env_ver = '.'.join(int_ver)
+            split_ver.pop()
+            env_ver = '.'.join(split_ver)
             if op == '==':
                 if marker == 'python_full_version':
                     marker = 'python_version'
@@ -390,7 +391,16 @@ def check_environment_marker_restrictions(req, marker_str, impl):
                          op, req)
                 return False
 
-        int_ver = [int(x) for x in int_ver]
+        int_ver = []
+        for ver_part in split_ver:
+            if ver_part.isdigit():
+                int_ver.append(int(ver_part))
+            else:
+                env_ver = '.'.join(str(x) for x in int_ver)
+                log.info('Truncating unparseable version %s to %s in %s',
+                         value, env_ver, req)
+                break
+
         if len(int_ver) < version_parts:
             int_ver.append(0)
             env_ver += '.0'
@@ -401,25 +411,34 @@ def check_environment_marker_restrictions(req, marker_str, impl):
         prev_ver[version_parts - 1] -= 1
         prev_ver = '.'.join(str(x) for x in prev_ver)
 
+        # We try to do something somewhat sensible with micro versions
+        # even though we don't currently emit them in python3-supported-min/max
+
         if op == '<':
             if int_ver <= [3, 0, 0]:
                 return False
-            return '| python3 (>> {})'.format(env_ver)
+            return '| python3-supported-min (>= {})'.format(env_ver)
         elif op == '<=':
-            return '| python3 (>> {})'.format(next_ver)
+            return '| python3-supported-min (>> {})'.format(env_ver)
         elif op == '>=':
             if int_ver < [3, 0, 0]:
                 return True
-            return '| python3 (<< {})'.format(env_ver)
+            return '| python3-supported-max (<< {})'.format(env_ver)
         elif op == '>':
             if int_ver < [3, 0, 0]:
                 return True
-            return '| python3 (<< {})'.format(next_ver)
-        elif op in ('==', '==='):
-            # === is arbitrary equality (PEP 440)
-            if marker == 'python_version' or op == '==':
-                return '| python3 (<< {}) | python3 (>> {})'.format(
+            return '| python3-supported-max (<= {})'.format(env_ver)
+        elif op == '==':
+            if marker == 'python_version':
+                return '| python3-supported-max (<< {}) | python3-supported-min (>= {})'.format(
                         env_ver, next_ver)
+            return '| python3-supported-max (<< {}) | python3-supported-min (>> {})'.format(
+                    env_ver, env_ver)
+        elif op == '===':
+            # === is arbitrary equality (PEP 440)
+            if marker == 'python_version':
+                return '| python3-supported-max (<< {}) | python3-supported-min (>> {})'.format(
+                        env_ver, env_ver)
             else:
                 log.info(
                     'Skipping requirement with %s environment marker, cannot '
@@ -429,7 +448,7 @@ def check_environment_marker_restrictions(req, marker_str, impl):
             ceq_next_ver = int_ver[:2]
             ceq_next_ver[1] += 1
             ceq_next_ver = '.'.join(str(x) for x in ceq_next_ver)
-            return '| python3 (<< {}) | python3 (>> {})'.format(
+            return '| python3-supported-max (<< {}) | python3-supported-min (>= {})'.format(
                     env_ver, ceq_next_ver)
         elif op == '!=':
             log.info('Ignoring != comparison in environment marker, cannot '
@@ -578,7 +597,8 @@ def ci_regexp(name):
     return ''.join("[%s%s]" % (i.upper(), i) if i.isalpha() else i for i in name.lower())
 
 
-PRE_VER_RE = re.compile(r'[-.]?(alpha|beta|rc|dev|a|b|c)')
+PEP386_PRE_VER_RE = re.compile(r'[-.]?(alpha|beta|rc|dev|a|b|c)')
+PEP440_PRE_VER_RE = re.compile(r'[-.]?(a|b|rc)')
 GROUP_RE = re.compile(r'\$(\d+)')
 
 
@@ -650,7 +670,9 @@ def _translate(version, rules, standard):
         else:
             log.warn('unknown rule ignored: %s', rule)
     if standard == 'PEP386':
-        version = PRE_VER_RE.sub(r'~\g<1>', version)
+        version = PEP386_PRE_VER_RE.sub(r'~\g<1>', version)
+    elif standard == 'PEP440':
+        version = PEP440_PRE_VER_RE.sub(r'~\g<1>', version)
     return version
 
 
